UML diagram figure
===================

Figure 1 in the software paper was generated by running the command

.. code-block:: bash
    pyreverse -S -o svg coil_optimize.py contour.py integrals.py line_conductor.py line_magnetics.py mesh_calculus.py mesh_conductor.py mesh_impedance.py mesh_magnetics.py sphtools.py suhtools.py utils.py viz.py
    
from the directory .../bfieldtools/bfieldtools. The output SVG figure was manually tweaked (the font was changed from serif to sans-serif) and saved with the filename packages_bfieldtools.svg. Finally, the tweaked file was converted to PDF.
